/**
 * ErrorPage
 * when page not found go (redirect) home ("/")
 */
import { useState, ReactNode } from "react";
import {
  Typography,
  Box,
  Accordion,
  AccordionSummary,
  AccordionDetails,
  useMediaQuery,
  TypographyProps
} from "@mui/material";
import ExpandMoreIcon from "@mui/icons-material/ExpandMore";
import { ExternalButtonLink, InternalButtonLink } from "../Link";
import { theme } from "../../../style/Theme";

export interface ErrorPageProps {
  title: string;
  subtitle: string;
  details?: string;
  SecondaryActionComponent?: ReactNode;
  mascotVariantL?: ReactNode;
  mascotVariantR?: ReactNode;
  supportHref?: string;
  titleProps?: TypographyProps;
  subtitleProps?: TypographyProps;
}

export const ErrorPage = ({
  title,
  subtitle,
  details,
  SecondaryActionComponent,
  mascotVariantL,
  mascotVariantR,
  supportHref,
  titleProps,
  subtitleProps
}: ErrorPageProps) => {
  const [showDetails, setShowDetails] = useState(false);
  const isDesktop = useMediaQuery(theme.breakpoints.up("sm"));

  const toggleDetails = () => {
    setShowDetails(!showDetails);
  };

  return (
    <>
      <Box
        display="flex"
        flexDirection="column"
        alignItems="center"
        gap={2}
      >
        <Box
          display="flex"
          flexDirection="row"
          alignItems="center"
          gap={2}
        >
          {mascotVariantL}
          <Box
            display="flex"
            flexDirection="column"
            alignItems="center"
            gap={2}
          >
            <Typography
              variant="h3"
              {...subtitleProps}
            >
              {subtitle}
            </Typography>
            <Typography
              variant="h2"
              {...titleProps}
            >
              {title}
            </Typography>
          </Box>
          {mascotVariantR}
        </Box>
        {details ? (
          <Accordion
            expanded={showDetails}
            onChange={toggleDetails}
            sx={{ maxWidth: isDesktop ? "50%" : "100%" }}
          >
            <AccordionSummary
              id="error-details-header"
              aria-controls="error-details-content"
              expandIcon={<ExpandMoreIcon />}
            >
              <Typography variant="body1">
                {showDetails ? "Hide Details" : "Show Details"}
              </Typography>
            </AccordionSummary>
            <AccordionDetails
              sx={{
                whiteSpace: "pre",
                overflow: "scroll"
              }}
            >
              <Typography
                variant="body2"
                fontFamily="monospace"
              >
                {details}
              </Typography>
            </AccordionDetails>
          </Accordion>
        ) : null}
        <Box
          display="flex"
          justifyContent="center"
          gap={2}
        >
          {SecondaryActionComponent ?? (
            <InternalButtonLink to="/">Return to Home</InternalButtonLink>
          )}

          {supportHref && (
            <ExternalButtonLink to={supportHref}>
              Contact Support
            </ExternalButtonLink>
          )}
        </Box>
      </Box>
    </>
  );
};
