import { ReactNode } from "react";
import { Button, Link, Stack, ButtonProps, LinkProps } from "@mui/material";
import { Link as RouterLink } from "react-router-dom";
import LaunchIcon from "@mui/icons-material/Launch";

interface LinkDefaultProps {
  to: string;
  label?: string;
  disableExternalLinkIcon?: boolean;
  children: string | ReactNode;
}

interface LinkContentProps {
  disableExternalLinkIcon: boolean;
  children: string | ReactNode;
}

const LinkContent = ({
  disableExternalLinkIcon,
  children
}: LinkContentProps) => {
  return (
    <>
      {disableExternalLinkIcon ? (
        children
      ) : (
        <Stack
          flexDirection="row"
          alignItems="center"
          gap={0.5}
        >
          {children}
          <LaunchIcon fontSize="small" />
        </Stack>
      )}
    </>
  );
};

export interface ExternalLinkProps extends LinkDefaultProps {
  LinkProps?: LinkProps;
}

export const ExternalLink = ({
  to,
  label,
  disableExternalLinkIcon = false,
  LinkProps,
  children
}: ExternalLinkProps) => (
  <Link
    component={RouterLink}
    to={to}
    target="_blank"
    aria-label={label || ""}
    {...LinkProps}
  >
    <LinkContent disableExternalLinkIcon={disableExternalLinkIcon}>
      {children}
    </LinkContent>
  </Link>
);

export interface ExternalButtonLinkProps extends LinkDefaultProps {
  ButtonProps?: ButtonProps;
}

export const ExternalButtonLink = ({
  to,
  label,
  disableExternalLinkIcon = false,
  ButtonProps,
  children
}: ExternalButtonLinkProps) => {
  return (
    <Button
      component={RouterLink}
      to={to}
      target="_blank"
      aria-label={label || ""}
      variant="outlined"
      {...ButtonProps}
    >
      <LinkContent disableExternalLinkIcon={disableExternalLinkIcon}>
        {children}
      </LinkContent>
    </Button>
  );
};
